#!/usr/bin/env bash

# Echo commands and exit on first error
set -xe

export REAL_CONDA_SP_DIR=$(readlink -f $CONDA_SP_DIR)

# Install ScopeSIM, not yet a conda package.
pip install skycalc_ipy
pip install git+https://github.com/astronomyk/ScopeSim.git
# TODO: Fetch data package.

# Do some non database tests.
env \
    database_engine=filebased \
    database_user=AWANONYMOUS \
  pytest -s --cov=${CONDA_SP_DIR}/micado \
    src/micado/test/functional/

# Do tests that require database.
if [[ ! -z ${GITLAB_CI+x} ]]; then
    export \
        database_tablespacename="pg_default" \
        database_engine="postgresql" \
        database_port="5432" \
        database_name="postgres/${POSTGRES_DB}" \
        database_user="${POSTGRES_USER}" \
        database_password="${POSTGRES_PASSWORD}"
fi

if [[ ${database_engine:-filebased} != filebased ]]; then
    # Create database structures for all persistent classes.
    env
        ask_administrator_password="False" \
    coverage run --append --source=${CONDA_SP_DIR}/micado -m \
        micado.toolbox.backends.postgresql.dbtestsetup

    # Run tests.
    env \
        database_user="AWTEST" \
        database_password="lmno" \
    python -m pytest --cov=${CONDA_SP_DIR}/micado --cov-append \
        src/micado/test/database
fi

# Generate coverage report.
coverage report -m | sed "s|$REAL_CONDA_SP_DIR|\$CONDA_SP_DIR|g"
