#******************************************************************************
# E.S.O. - VLT project
#
# "@(#) $Id: ESO-VLT-DIC.PRO,v 1.3 2001/06/21 15:00:41 ndevilla Exp $"
#
# who       when      what
# --------  --------  ----------------------------------------------
# sbogun    01/04/98  V0.1 - first draft
# sbogun    28/09/98  V0.8 - DMD/DPG internal revision:
#                            class reduc-log removed
#                            RECi keywords introduced
#                            QC keywords updated
#                            QAK keywords removed
# sbogun    07/10/98  V0.9 - submitted to DICB
# sbogun    09/10/98  V1.0 - comments by M. Albrecht included
#                            PIPEFILE introduced
#                            PRO RECi PARMj changed to PRO RECi ARGj
#                            PRO RECi ARGj TYPE introduced
#                            DATAMODE, PRO QC SKYMODE removed
# sbogun    21/10/98  V1.1 - Changes in descriptions of some keys
#                            Minor changes
# sbogun    10/12/98  V1.2 - Internal DPG review
# sbogun    18/12/98  V1.3 - Keywords DATAMEAN, DATASIG, DATAMEDI, DATANCOM,
#                             moved to process context
#                            format %.1f changed to %e
#                            format of PIPEFILE changed to %64s
#                            format of PRO RB ID changed to %50s
#                            format of PRO QC ARCFILE changed to %48s
#                            class of keywords PRO SKY ... changed to private
#                            class of keywords PRO QC IMGQUAL, PRO QC LIMAG
#                             changed to private
#                            format of PRO QC STATUS changed to %9s
#                            PRO ID replaced by PRO DO ID, PRO RBS ID and
#                             PRO QC ID
#                            description of some keywords improved
#                            keywords PRO QC ZPOINT and PRO QC EXTCOEFF
#                             introduced
#                            PRO REDLEVEL: combinations of values allowed
#                            PRO QC LEVEL removed
#                            PRO RECi ARGj NAMEk created, contains parameter
#                             name 
# sbogun    08/03/99  V1.4 - Keyword PRO QC IMGQUNC added
# sbogun    24/03/99  V1.5 - PRO REDLEVEL slightly modified
#                            comments shortened
# sbogun    19/08/99  V1.6 - Description of PRO REDLEVEL modified
#                            PRO STATUS renamed to PRO RECi STATUS
#                            PRO DATE removed
#                            PRO RF ID added     
#                            PRO STRATEGY added
#                            PRO EXPTTOT added
#                            PRO QC OUTi OVBIAS added
#                            PRO QC OUTi OVNOISE added
#                            PRO RECi ARGj TYPE removed
#                            PRO RECi ARGj NAMEk removed
#                            PRO RECi ARGj VALUEk removed
#                            PRO RECi ARGj CATGk removed
# sbogun    19/11/99  V1.7 - QC keywords moved to new QUC dictionary
#                            format %e changed to %.?f
#                            PRO QC ARCFILE renamed to PRO ARCFILE
# sbogun    06/02/01  V1.8 - PRO STRATEGY removed
#                            PRO FC ID removed
#                            PRO KM ID removed
#                            PRO RF ID removed
#                            PRO RECi PIPE ID added
#                            Description of PRO CATG and PRO RECi ID modified
#                            PRO RECi RAWj NAME added
#                            PRO RECi RAWj TYPE added
#                            PRO RECi CALIBj NAME added
#                            PRO RECi CALIBj TYPE added
#                            PRO RECi PARAMj NAME added
#                            PRO RECi PARAMj (S/L/I/D)VALUE added
#                            Guidelines added to dictionary header
# sbogun    06/03/01  V1.9 - PRO RECi RAWj TYPE ren. to PRO RECi RAWj CATG
#                            PRO RECi CALIBj TYPE ren. to PRO RECi CALIBj CATG
# sbogun    07/03/01  V1.10- Date field made ISO 8601 conform
# sbogun    12/03/01  V1.11- Index j renamed to i
#                            DATAMIN, DATAMAX removed
# sbogun    23/03/01  V1.12- keywords PRO DATAMEAN, PRO DATAMEDI and
#                            PRO DATASIG renamed for DICD compliance
# sbogun    21/06/01  V1.13- PRO RECi CALIBi * renamed to PRO RECi CALi *
#                            keyword DATAMD5 added
#                            keyword PRO RECi CALi DATAMD5 added
#                            PRO DATASDV renamed to PRO DATARMS
#                            
#******************************************************************************
#   NAME
#   ESO-VLT-DIC.PRO - Data Interface Dictionary for data reduction process
#                     description
# -----------------------------------------------------------------------------
#
# Guidelines for creation of pipeline product headers
# ---------------------------------------------------
# 
# 
# The FITS header of a pipeline data product consists of three kinds of
# keywords:
# 
#  - Keywords already present in the raw frame(s) that lead to the
#    data product. All these keywords are defined in the instrument
#    dictionaries or TCS, CCD, ... dictionaries.
# 
#  - Keywords that describe the data product itself. These keywords
#    must be defined in the PRO dictionary.
# 
#  - Keywords that describe results of Quality Control tasks performed by
#    the pipeline. These keywords must be defined in an instrument-specific
#    dictionary called ESO-DFS-DIC.<instrument-name>_QC.
# 
# Each individual instrument pipeline is responsible to equip the data
# product with a proper FITS header. This includes:
# 
#  - All keywords specified in the PRO dictionary which apply to a
#    given data product must be written into the header.
# 
#  - Keywords inherited from the input frame(s) which don't have a meaning
#    for the data product or are obsolete must be deleted. Examples:
#     - a flux calibrated image must not contain detector keywords
#     - a master calibration frame must not contain keywords that
#       are relevant only for the individual input frames.
# 
#  - The MD5 data signature must be computed for each data product and
#    written to the keyword 'DATAMD5'.
#
#  - The PRO RECi hierarchy in a data product header must reflect
#    the processing history of the frame. This means that the first recipe
#    applied to a raw frame must write a group of keywords starting with
#    PRO REC1, while, if this product is processed by another recipe, the
#    resulting frame must contain additionally a group of keywords
#    starting with PRO REC2, and so forth.
# 
#  - The header should be sorted w.r.t. the PRO RECi hierarchies, this
#    means that the keywords 'PRO REC1 *' must appear before 'PRO REC2 *'
#    and so on.
# 
#  - The archive file names of input frames must be written into the
#    FITS keywords HIERARCH ESO PRO RECi RAWi NAME, their DO categories
#    in the keywords HIERARCH ESO PRO RECi RAWi CATG. 
#
#  - The archive file names of reference frames must be written into the
#    FITS keywords HIERARCH ESO PRO RECi CALi NAME, their DO categories
#    in the keywords HIERARCH ESO PRO RECi CALi CATG and their MD signatures
#    in the keywords HIERARCH ESO PRO RECi CALi DATAMD5.
#
#    Examples:
#    HIERARCH ESO PRO REC1 RAW1 NAME = 'FORS2.2000-10-30T13:27:51.451.fits'
#    HIERARCH ESO PRO REC1 RAW1 CATG = 'BIAS'
#
#    HIERARCH ESO PRO REC1 CAL1 NAME = 'r.UVES.1999-03-27T11:27:51.652.fits'
#    HIERARCH ESO PRO REC1 CAL1 CATG = 'MASTER_BIAS'
#    HIERARCH ESO PRO REC1 CAL1 DATAMD5 = 'ad34l2k5j321ajsdhwji2312l435323'
#
#  - Names of parameters passed to the recipe are written into the keywords
#    HIERARCH ESO PRO RECi PARAMi NAME, their values are written to
#    HIERARCH ESO PRO RECi PARAMi SVALUE/LVALUE/IVALUE/DVALUE, depending on
#    their data type.
#
#    Examples:
#    HIERARCH ESO PRO REC1 PARAM1 NAME = 'THRESH'
#    HIERARCH ESO PRO REC1 PARAM1 DVALUE = 1.0
#
#  - Each PRO RECi keyword group should look as follows:
# 
#     HIERARCH ESO PRO RECi START  = <value> / <comment>
#     HIERARCH ESO PRO RECi ID     = <value> / <comment>
#     HIERARCH ESO PRO RECi DRS ID = <value> / <comment>
#     HIERARCH ESO PRO RECi RAW1 NAME = <value>
#     HIERARCH ESO PRO RECi RAW1 CATG = <value>
#     HIERARCH ESO PRO RECi RAW2 NAME = <value>
#     HIERARCH ESO PRO RECi RAW2 CATG = <value>
#         ...
#     HIERARCH ESO PRO RECi CAL1 NAME = <value>
#     HIERARCH ESO PRO RECi CAL1 CATG = <value>
#     HIERARCH ESO PRO REC1 CAL1 DATAMD5 = 'ad34l2k5j321ajsdhwji2312l435323'
#     HIERARCH ESO PRO RECi CAL2 NAME = <value>
#     HIERARCH ESO PRO RECi CAL2 CATG = <value>
#     HIERARCH ESO PRO REC1 CAL2 DATAMD5 = 'to34649fgsvcz9kr39332l432502aas'
#         ...
#     HIERARCH ESO PRO RECi PARAM1 NAME = <value> / <comment>
#     HIERARCH ESO PRO RECi PARAM1 DVALUE = <value> / <comment>
#     HIERARCH ESO PRO RECi PARAM2 NAME = <value> / <comment>
#     HIERARCH ESO PRO RECi PARAM2 SVALUE = <value> / <comment>
#         ...
#     HIERARCH ESO PRO RECi STOP   = <value> / <comment>
# 
#     Examples for FORS and ISAAC can be found below.
# 
#  - Possible values for the keyword PRO REDLEVEL are
#    instrument-dependent, for FORS the values "DETECTOR", "GEOMETRIC",
#    "PHOTOMETRIC" are allowed. The values used for a given
#    instrument must be listed in the instrument pipeline user manual.
# 
# 
# 
# -----------------------------------------------------------------------------
# 
# 
# Example of a FORS product header (RECi part):
# 
# HIERARCH ESO PRO REC1 START  = '1999-04-23T07:38:04.530' / Start date of execu
# HIERARCH ESO PRO REC1 ID     = 'fors_s_img_stdstar' / Pipeline recipe (unique)
# HIERARCH ESO PRO REC1 DRS ID = 'ESO-MIDAS/98NOVpl2.1' / Data Reduction System 
# HIERARCH ESO PRO REC1 PIPE ID = 'FORS/1.7.0' / Pipeline (unique) identifier
# HIERARCH ESO PRO REC1 RAW1 NAME = 'FORS.1999-05-21T17:19:39.399.fits'
# HIERARCH ESO PRO REC1 RAW1 CATG = 'STANDARD_IMG'
# HIERARCH ESO PRO REC1 CAL1 NAME = 'r.FORS.1999-05-21T17:19:39.399_tpl_0000.fits'
# HIERARCH ESO PRO REC1 CAL1 CATG = 'MASTER_BIAS'
# HIERARCH ESO PRO REC1 CAL1 DATAMD5 = '539648345kkl43i5p2jjjj42u582343'
# HIERARCH ESO PRO REC1 CAL2 NAME = 'r.FORS.2000-12-24T07:40:24.996_tpl_0000.fits'
# HIERARCH ESO PRO REC1 CAL2 CATG = 'MASTER_SKY_FLAT_IMG'
# HIERARCH ESO PRO REC1 CAL2 DATAMD5 = 'hglv003pqaozz012o424j235oadso11'
# HIERARCH ESO PRO REC1 CAL3 NAME = 'r.FORS.2000-12-01T04:36:02.332_tpl_0000.fits'
# HIERARCH ESO PRO REC1 CAL3 CATG = 'BAD_PIXEL_TABLE'
# HIERARCH ESO PRO REC1 CAL3 DATAMD5 = 'federtew6003945i31123kfdsk131k2'
# HIERARCH ESO PRO REC1 PARAM1 NAME = 'BIASCONS' / Bias constant subtracted from 
# HIERARCH ESO PRO REC1 PARAM1 IVALUE = 0
# HIERARCH ESO PRO REC1 PARAM2 NAME = 'DARKCONS' / Dark constant subtracted from 
# HIERARCH ESO PRO REC1 PARAM2 IVALUE = 0
# HIERARCH ESO PRO REC1 STOP   = '1999-04-23T07:39:04.530' / End date of executi
# HIERARCH ESO PRO REC2 START  = '1999-04-23T07:58:04.530' / Start date of execu
# HIERARCH ESO PRO REC2 ID     = 'fors_img_cal_extcoeff/1.2' / Pipeline recipe (
# HIERARCH ESO PRO REC2 DRS ID = 'ESO-MIDAS/98NOVpl2.1' / Data Reduction System 
# HIERARCH ESO PRO REC2 PIPE ID = 'FORS/1.7.0' / Pipeline (unique) identifier
# HIERARCH ESO PRO REC2 RAW1 NAME = 'r.FORS.1999-05-21T17:19:39.399.fits'
# HIERARCH ESO PRO REC2 RAW1 CATG = 'ALIGNED_PHOTOMETRY_TABLE'
# HIERARCH ESO PRO REC2 CAL1 NAME = 'purge.tfits'
# HIERARCH ESO PRO REC2 CAL1 CATG = DESC_PURGE_TABLE'
# HIERARCH ESO PRO REC2 CAL1 DATAMD5 = '11o4kfs90345jhsdfu32jasaw904234'
# HIERARCH ESO PRO REC2 PARAM1 NAME = 'FIT_MODE' / Fitting algorithm used
# HIERARCH ESO PRO REC2 PARAM1 SVALUE = 'ROB     '
# HIERARCH ESO PRO REC2 PARAM2 NAME = 'SNMIN   ' / Min. S/N ratio of star detecti
# HIERARCH ESO PRO REC2 PARAM2 DVALUE = 150.0
# HIERARCH ESO PRO REC2 STOP   = '1999-04-23T08:58:04.530' / End date of executio
# 
# 
# Example of a ISAAC product header (RECi part):
# 
# HIERARCH ESO PRO REC1 START  = '1999-04-24T08:38:04.530' / Start date of execu
# HIERARCH ESO PRO REC1 ID     = 'img_jitter'  / Pipeline recipe (unique) identi
# HIERARCH ESO PRO REC1 DRS ID = 'ESO-MIDAS/98NOVpl2.1' / Data Reduction System 
# HIERARCH ESO PRO REC1 PIPE ID = ISAAC/2.1.2' / Pipeline (unique) identifier
# HIERARCH ESO PRO REC1 RAW1 NAME = 'dark-DIT=10.fits'
# HIERARCH ESO PRO REC1 RAW1 CATG = 'DARK'
# HIERARCH ESO PRO REC1 CAL1 NAME = 'twflat_h.fits'
# HIERARCH ESO PRO REC1 CAL1 CATG = 'TWFLAT'
# HIERARCH ESO PRO REC1 CAL1 DATAMD5 = '4353gdfgkl453o45dfklsdfl3252344'
# HIERARCH ESO PRO REC1 PARAM1 NAME = 'SKY ACTIVE' 
# HIERARCH ESO PRO REC1 PARAM1 IVALUE = 1
# HIERARCH ESO PRO REC1 PARAM2 NAME = 'SKY REJHW'  
# HIERARCH ESO PRO REC1 PARAM2 IVALUE = 3
# HIERARCH ESO PRO REC1 PARAM3 NAME = 'SKY REJMIN' 
# HIERARCH ESO PRO REC1 PARAM3 IVALUE = 1
# HIERARCH ESO PRO REC1 PARAM4 NAME = 'SKY REJMAX' 
# HIERARCH ESO PRO REC1 PARAM4 IVALUE = 1
# HIERARCH ESO PRO REC1 PARAM5 NAME = 'SAA ACTIVE' 
# HIERARCH ESO PRO REC1 PARAM5 IVALUE = 1
# HIERARCH ESO PRO REC1 PARAM6 NAME = 'SAA OFFS'   
# HIERARCH ESO PRO REC1 PARAM6 SVALUE = 'header'
# HIERARCH ESO PRO REC1 PARAM7 NAME = 'SAA DETTH'  
# HIERARCH ESO PRO REC1 PARAM7 DVALUE = 3.0
# HIERARCH ESO PRO REC1 PARAM8 NAME = 'SAA DETMIN' 
# HIERARCH ESO PRO REC1 PARAM8 IVALUE = 1
# HIERARCH ESO PRO REC1 PARAM9 NAME = 'SAA DETMAX' 
# HIERARCH ESO PRO REC1 PARAM9 IVALUE = 10
# HIERARCH ESO PRO REC1 PARAM10 NAME = 'SAA SX  '   
# HIERARCH ESO PRO REC1 PARAM10 IVALUE = 15
# HIERARCH ESO PRO REC1 PARAM11 NAME = 'SAA SY  '   
# HIERARCH ESO PRO REC1 PARAM11 IVALUE = 15
# HIERARCH ESO PRO REC1 PARAM12 NAME = 'SAA HX  '   
# HIERARCH ESO PRO REC1 PARAM12 IVALUE = 35
# HIERARCH ESO PRO REC1 PARAM13 NAME = 'SAA HY  '   
# HIERARCH ESO PRO REC1 PARAM13 IVALUE = 35
# HIERARCH ESO PRO REC1 PARAM14 NAME = 'REG ACTIVE' 
# HIERARCH ESO PRO REC1 PARAM14 IVALUE = 1
# HIERARCH ESO PRO REC1 PARAM15 NAME = 'REG SUBPIX' 
# HIERARCH ESO PRO REC1 PARAM15 IVALUE = 1
# HIERARCH ESO PRO REC1 PARAM16 NAME = 'REG KERNEL' 
# HIERARCH ESO PRO REC1 PARAM16 SVALUE = 'tanh'
# HIERARCH ESO PRO REC1 PARAM17 NAME = 'AVG ACTIVE' 
# HIERARCH ESO PRO REC1 PARAM17 IVALUE = 1
# HIERARCH ESO PRO REC1 PARAM18 NAME = 'AVG TYPE'   
# HIERARCH ESO PRO REC1 PARAM18 SVALUE = 'filtered'
# HIERARCH ESO PRO REC1 PARAM19 NAME = 'AVG FILTMIN'
# HIERARCH ESO PRO REC1 PARAM19 DVALUE = 0.05
# HIERARCH ESO PRO REC1 PARAM20 NAME = 'AVG FILTMAX'
# HIERARCH ESO PRO REC1 PARAM20 DVALUE = 0.05
# HIERARCH ESO PRO REC1 STOP   = '1999-04-24T08:58:04.530' / End date of executio
# 
# 
# 
# -----------------------------------------------------------------------------

Dictionary Name:   ESO-VLT-DIC.PRO
Scope:             PRO
Source:            ESO DFS/DMD
Version Control:   "@(#) $Id: ESO-VLT-DIC.PRO,v 1.3 2001/06/21 15:00:41 ndevilla Exp $"
Revision:          0.1
Date:              1998-04-01
Status:            draft
Description:       first draft, based on ESO-NTT-DIC.PRO, 1996-12-06
Revision:          0.8
Date:              1998-09-28
Status:            draft
Description:       DMD/DPG internal revision
Revision:          0.9
Date:              1998-10-07
Status:            submitted
Description:       submitted to DICB
Revision:          1.0
Date:              1998-10-09
Status:            submitted
Description:       comments by M. Albrecht included, submitted to DICB
Revision:          1.1
Date:              1998-10-21
Status:            submitted
Description:       Minor changes
Revision:          1.2
Date:              1998-12-10
Status:            submitted
Description:       internal DPG review
Revision:          1.3
Date:              1998-12-18
Status:            approved
Description:       Change requests from DICB meeting of 01/12/98 introduced
Revision:          1.4
Date:              1999-03-08
Status:            submitted
Description:       keyword PRO QC IMGQUNC added
Revision:          1.5
Date:              1999-03-24
Status:            submitted
Description:       comments shortened
Revision:          1.6
Date:              1999-08-19
Status:            submitted
Description:       Major revision due to internal DPG discussion
Revision:          1.7
Date:              1999-11-19
Status:            submitted
Description:       QC keywords moved to new QUC dictionary
Revision:          1.8
Date:              2001-02-20
Status:            submitted
Description:       File and parameter naming scheme revised
Revision:          1.9
Date:              2001-03-06
Status:            submitted
Description:       PRO RECi * TYPE ren. to PRO RECi * CATG
Revision:          1.10
Date:              2001-03-07
Status:            submitted
Description:       Date field made ISO 8601 conform
Revision:          1.11
Date:              2001-03-12
Status:            submitted
Description:       Index j renamed to i
                   DATAMIN, DATAMAX removed
Revision:          1.12
Date:              2001-03-23
Status:            submitted
Description:       keywords PRO DATAMEAN, PRO DATAMEDI and
                   PRO DATASIG renamed for DICD compliance
Revision:          1.13
Date:              2001-06-21
Status:            submitted
Description:       PRO RECi CALIBi * renamed to PRO RECi CALi *
                   keyword DATAMD5 added
                   keyword PRO RECi CALi DATAMD5 added
                   PRO DATASDV renamed to PRO DATARMS

#
# Basic FITS keywords

Parameter Name:    PIPEFILE
Class:             header
Context:           FITS
Type:              string
Value Format:      %64s
Unit:              
Comment Field:     Filename of data product
Description:       Filename of data product as created by the pipeline.

Parameter Name:    DATAMD5
Class:             header
Context:           FITS
Type:              string
Value Format:      %32s
Unit:
Comment Field:     MD5 data signature
Description:       This field holds the MD5 signature of all data
                   sections contained in the FITS file. It is useful
                   to provide a unique identity to a file belonging to
                   a group. Even if the signature is not guaranteed
                   to be unique, the probability of a collision is
                   of the order of 2^-128 (1e-39), which should be good
                   enough to identify files in a filesystem.
                   The string describes a 128-bit number, i.e. 16 bytes
                   written in hexa on 32 characters.

#
# Process category

Parameter Name:    PRO DID
Class:             header
Context:           process
Type:              string
Value Format:      %30s
Unit:              
Comment Field:     Data dictionary for PRO
Description:       Name/version of ESO DID to which PRO keywords comply.

Parameter Name:    PRO DO ID
Class:             header
Context:           process
Type:              string
Value Format:      %30s
Unit:              
Comment Field:     Data Organizer identification ID
Description:       Identification of the Data Organizer subsystem.
                   Format: DO-<version_ID>.

Parameter Name:    PRO RBS ID
Class:             header
Context:           process
Type:              string
Value Format:      %30s
Unit:              
Comment Field:     Reduction Block Scheduler identification ID
Description:       Identification of the Reduction Block Scheduler subsystem.
                   Format: RBS-<version_ID>.

Parameter Name:    PRO TYPE
Class:             header
Context:           process
Type:              string
Value Format:      %20s
Unit:              
Comment Field:     Product type
Description:       Identification of type of data product.
                   Value: either "TEMPORARY", "PREPROCESSED", "REDUCED" or
                   "QCPARAM".

Parameter Name:    PRO REDLEVEL
Class:             header
Context:           process
Type:              string
Value Format:      %31s
Unit:              
Comment Field:     Reduction level of data product
Description:       Reduction level of this data product. 
                   Possible values depend on the instrument. See instrument
                   pipeline user manual for description.

Parameter Name:    PRO CATG
Class:             header
Context:           process
Type:              string
Value Format:      %30s
Unit:              
Comment Field:     Category of pipeline product frame
Description:       Category of pipeline product defined in the instrument's
                   product data description file (pdd).

Parameter Name:    PRO RB ID
Class:             header
Context:           process
Type:              string
Value Format:      %50s
Unit:              
Comment Field:     Reduction Block identifier
Description:       Identification of Reduction Block file (without directory).

Parameter Name:    PRO RECi ID
Class:             header
Context:           process
Type:              string
Value Format:      %32s
Unit:              
Comment Field:     Pipeline recipe (unique) identifier
Description:       Identification of pipeline recipe which produced
                   the frame. Note: If frame is generated from raw data
                   i=1, otherwise PRO REC1 ID, PRO REC2 ID, ... reflect
                   the processing history.
                   Format: Recipe-name.

Parameter Name:    PRO RECi START
Class:             header
Context:           process
Type:              string
Value Format:      %30s
Unit:              
Comment Field:     Date when recipe execution started
Description:       Date when recipe execution started (ISO 8601).

Parameter Name:    PRO RECi STOP
Class:             header
Context:           process
Type:              string
Value Format:      %30s
Unit:              
Comment Field:     Date when recipe execution finished
Description:       Date when recipe execution finished (ISO 8601).

Parameter Name:    PRO RECi DRS ID
Class:             header
Context:           process
Type:              string
Value Format:      %20s
Unit:              
Comment Field:     Data Reduction System identifier
Description:       Identification of Data Reduction system used.
                   Format: DRS-name/version.

Parameter Name:    PRO RECi PIPE ID
Class:             header
Context:           process
Type:              string
Value Format:      %32s
Unit:              
Comment Field:     Pipeline (unique) identifier
Description:       Identification of the instrument pipeline which produced
                   the frame.
                   Format: Pipeline-name/version.

Parameter Name:    PRO RECi RAWi NAME
Class:             header
Context:           process
Type:              string
Value Format:      %45s
Unit:              
Comment Field:     File name of raw frame
Description:       File name of raw frame.

Parameter Name:    PRO RECi RAWi CATG
Class:             header
Context:           process
Type:              string
Value Format:      %32s
Unit:              
Comment Field:     Frame category of raw frame
Description:       Category of the raw frame as given by the instrument's .bdd
                   or .pdd file.

Parameter Name:    PRO RECi CALi NAME
Class:             header
Context:           process
Type:              string
Value Format:      %45s
Unit:              
Comment Field:     File name of calibration frame
Description:       File name of calibration frame.

Parameter Name:    PRO RECi CALi CATG
Class:             header
Context:           process
Type:              string
Value Format:      %32s
Unit:              
Comment Field:     Frame category of calibration frame
Description:       Category of the calibration frame as given by the instrument's
                   .pdd file.

Parameter Name:    PRO RECi CALi DATAMD5
Class:             header
Context:           process
Type:              string
Value Format:      %32s
Unit:
Comment Field:     MD5 data signature of calibration frame
Description:       This field holds the MD5 signature of all data
                   sections contained in the calibration file. It is useful
                   to provide a unique identity to a file belonging to
                   a group. Even if the signature is not guaranteed
                   to be unique, the probability of a collision is
                   of the order of 2^-128 (1e-39), which should be good
                   enough to identify files in a filesystem.
                   The string describes a 128-bit number, i.e. 16 bytes
                   written in hexa on 32 characters.

Parameter Name:    PRO RECi PARAMi NAME
Class:             header
Context:           process
Type:              string
Value Format:      %45s
Unit:              
Comment Field:     Name of recipe parameter
Description:       Name of parameter passed to the recipe.

Parameter Name:    PRO RECi PARAMi SVALUE
Class:             header
Context:           process
Type:              string
Value Format:      %32s
Unit:              
Comment Field:     Value of recipe parameter
Description:       Value of parameter passed to the recipe.

Parameter Name:    PRO RECi PARAMi LVALUE
Class:             header
Context:           process
Type:              logical
Value Format:      %c
Unit:              
Comment Field:     Value of recipe parameter
Description:       Value of parameter passed to the recipe.

Parameter Name:    PRO RECi PARAMi IVALUE
Class:             header
Context:           process
Type:              integer
Value Format:      %d
Unit:              
Comment Field:     Value of recipe parameter
Description:       Value of parameter passed to the recipe.

Parameter Name:    PRO RECi PARAMi DVALUE
Class:             header
Context:           process
Type:              double
Value Format:      %f
Unit:              
Comment Field:     Value of recipe parameter
Description:       Value of parameter passed to the recipe.

Parameter Name:    PRO RECi STATUS
Class:             header
Context:           process
Type:              string
Value Format:      %7s
Unit:              
Comment Field:     Pipeline status of frame
Description:       Pipeline status of product.
                   Valid fields are:
                   "INFO"    (not important warning, only emitted for 
                              information purposes)
                   "SERIOUS" (the warning is about something important, but
                              that did not prevent from producing data. User 
                              should take a look at the log files).
                   If the pipeline status of the frame is OK, the keyword is
                   omitted.
 
Parameter Name:    PRO DATAAVG
Class:             header
Context:           process
Type:              double
Value Format:      %.3f
Unit:              
Comment Field:     Mean of pixel values
Description:       Mean of the pixel values in the frame. All pixels are
                   taken into account.

Parameter Name:    PRO DATARMS
Class:             header
Context:           process
Type:              double
Value Format:      %.3f
Unit:              
Comment Field:     Standard deviation of pixel values
Description:       Population standard deviation (sigma) of the pixel values
                   in the frame. All pixels are taken into account.

Parameter Name:    PRO DATAMED
Class:             header
Context:           process
Type:              double
Value Format:      %.3f
Unit:              
Comment Field:     Median of pixel values
Description:       Exact median of the pixel values in the frame. All pixels
                   are taken into account.

Parameter Name:    PRO DATANCOM
Class:             header
Context:           process
Type:              integer
Value Format:      %d
Unit:              
Comment Field:     Number of frames combined
Description:       Number of input frames combined to compute data product.

Parameter Name:    PRO EXPTTOT
Class:             header
Context:           process
Type:              double
Value Format:      %.2f
Unit:              s
Comment Field:     Total exposure time of all frames combined
Description:       The sum of the exposure times of all frames combined to 
                   compute data product.

Parameter Name:    PRO ARCFILE
Class:             header
Context:           process
Type:              string
Value Format:      %48s
Unit:              
Comment Field:     Archive file name of raw data frame
Description:       The archive file name of the raw data frame that lead to
                   this data product. Only present if product results from
                   a single input frame.

