# -*- coding: utf-8 -*-
"""
The BaseFrame is the base class for all image-based classes.

It represents a single-layer image.
"""

import tempfile

from astropy.io import fits

from micado.main.DataItem import DataItem, persistent


class BaseFrame(DataItem):
    """
    BaseFrame
    """

    dummy_baseframe = persistent("dummy", int, 0)

    # TODO: use these time formats again

    format_time_filename = "%Y%m%dT%H%M%SS%f"
    # Format for strftime/strptime for filenames

    format_time_fitsheader = "%Y-%m-%dT%H:%M:%S.%f"
    # Format for strftime/strptime for fits headers

    def save_fits(self, filename: str = None):
        """
        Save as FITS file.
        """
        if not filename:
            if not self.filename:
                self.filename = tempfile.NamedTemporaryFile(suffix='.fits', delete=False).name
            filename = self.filename

        hduprimary = fits.PrimaryHDU(
            header=fits.Header(self.fits_keywords)
        )

        hdusextension = [fits.ImageHDU(
            data=ext.image,
            header=fits.Header(ext.fits_keywords),
        ) for ext in self.extensions]

        hdul = fits.HDUList([hduprimary] + hdusextension)
        hdul.writeto(filename, output_verify="fix", clobber=True)

        self.unique_filename()

    def unique_filename(self, input_filename=None, extra=None):
        """
        Generate unique filename.
        """
        DataItem.unique_filename(
            self,
            input_filename=input_filename,
            extra=[self.creation_date.strftime(self.format_time_filename)]
        )
