# -*- coding: utf-8 -*-
"""
Hardware that represents an effect.
"""

from micado.main.Hardware import Hardware, persistent


class Effect(Hardware):
    """
    Hardware that represents an effect.

    This class is necessary to overload scopesim_dictionary.
    """
    dummy2 = persistent("dummy2", str, "")

    @property
    def scopesim_dictionary(self):
        """
        Create ScopeSIM dictionary from value.
        """
        dd = super(Effect, self).scopesim_dictionary
        kwargs1 = dd.pop('kwargs')
        # Convert from OrderedDict to dict.
        # Do not pass empty values, e.g. filename, globalname.
        kwargs2 = {
            k: v
            for k, v in kwargs1.items()
            if v not in ['', None]
        }

        # Propagate observation properties to the effect.
        # TODO: find a more generic way to achieve this
        # TODO: also propagate to detector? see scopesim_test.py
        from micado.hardware.DarkCurrent import DarkCurrent
        if isinstance(self, DarkCurrent):
            kwargs2["dit"] = "!OBS.dit"
            kwargs2["ndit"] = "!OBS.ndit"

        dd['kwargs'] = kwargs2
        return dd
