# -*- coding: utf-8 -*-
"""
Tests for Detrend.py
"""

import os

from micado.config.Environment import Env
from micado.hardware.ShotNoise import ShotNoise
from micado.main.ObservingBlock import ObservingBlock
from micado.hardware.Detector import Detector
from micado.hardware.DetectorArray import DetectorArray
from micado.hardware.DarkCurrent import DarkCurrent
from micado.dataitems.Science import Science
from micado.dataitems.ScienceExtension import ScienceExtension
from micado.dataitems.Detrend import Detrend
from micado.dataitems.DetrendExtension import DetrendExtension
from micado.recipes.McdImgDetrend import McdImgDetrend
from micado.templates.MCD_img_sci_object import MCD_img_sci_object
from micado.util.esokeywords import verify_fitsheaders
from .MasterDark_test import create_masterdark


def test_processing():
    """
    Test processing of Detrend.
    """
    Env['use_python_logging'] = True
    myraws, mymasterdark, dark_real = create_masterdark()

    mydetector = Detector()
    mydetectorlist = [mydetector]
    mydarkcurrent = DarkCurrent(value=dark_real)
    myshotnoise = ShotNoise(state=True)

    mydetectorarray = DetectorArray(
        name='testdetector',
        detector_array_list=mydetectorlist,
        dark_current=mydarkcurrent,
        shot_noise=myshotnoise,
    )

    # A template
    science_template = MCD_img_sci_object(det__dit=1)

    # An observingblock
    science_ob = ObservingBlock(
        name="MyScienceTest",
        instrument="MICADO",
        target="empty_sky",
        templates=[science_template],
    )

    # Extensions
    myextensions = [
        ScienceExtension(detector=det, BITPIX=-64, NAXIS=2)
        for det in mydetectorlist
    ]

    # Create raws
    n_raws = 4
    myrawsscience = []
    for i in range(n_raws):
        myraw = Science(
            detector=mydetectorarray,
            template=science_template,
            observing_block=science_ob,
            extensions=myextensions,
        )
        myraw.make_simulation()
        myraw.save_fits()
        myrawsscience.append(myraw)

    myrawscience = myrawsscience[0]

    myrecipe = McdImgDetrend()
    mydetrend = Detrend(
        raw=myrawscience,
        masterdark=mymasterdark,
        # TODO: masterflat
        recipe=myrecipe,
    )
    mydetrend.make()
    mydetrend.save_fits()

    # TODO: Fix headers
    # verify_fitsheaders(mydetrend.filename)

    # TODO: add tests for pixel values
    # That is, everything should be 0 now

    for dm in myraws + myrawsscience:
        os.remove(dm.filename)
        os.remove(dm.filename_short)

    os.remove(mymasterdark.filename)
    os.remove(mymasterdark.filename_short)
