# -*- coding: utf-8 -*-
"""
Generate Template modules from .tsf files.

This file is not currently used. The template files are generated
from VODML instead. This file is used for sanity checks. It is not
clear in what format the actual templates will be delivered. This
file can be used again if that format is PAF.
"""

import glob
from collections import OrderedDict
from pathlib import Path

python_from_type = {
    'number': float,
    'integer': int,
    'keyword': str,
}

default_from_type = {
    'number': 0.0,
    'integer': 0,
    'keyword': "",
}

PATH_TEMPLATE_TSF = Path(__file__).resolve().parent.parent / "templates"
PATH_TEMPLATE_PY = PATH_TEMPLATE_TSF


def parse_line(line: str):
    """
    Parse a line.
    """
    name = line.split()[0]
    l2 = line[len(name):].strip()
    l2 += ";" if ";" not in l2 else ""
    v1, c1 = l2.split(";")
    value = v1.strip().strip('"').strip()
    comment = c1.strip(" #")
    return name, value, comment


def template_from_tsf(filename: str):
    """
    Create Template class from tsf file.
    """
    lines1 = open(filename).readlines()
    lines2 = [l.strip() for l in lines1 if len(l.strip())]
    lines3 = [l for l in lines2 if not l.startswith('#') and not l.startswith("PAF.HDR.")]
    lines4 = [parse_line(l) for l in lines3]

    names_params = [l[1] for l in lines4 if l[0] == "TPL.PARAM"]
    lines5 = [(l[0], (l[1], l[2])) for l in lines4 if not l[0] == "TPL.PARAM"]
    lines6 = OrderedDict(lines5)
    params = OrderedDict([
        (name, {
            attr.lower(): lines6.get("{}.{}".format(name, attr), (None, ""))
            for attr in ['TYPE', 'RANGE', 'DEFAULT', 'VALUE', 'LABEL', 'MINIHELP', 'HIDE']
        })
        for name in names_params])

    name_template = lines6["PAF.NAME"][0]
    doc_template = lines6["PAF.DESC"][0]

    list_attrs = [{
        # name.split(".")[1].lower():
        #  DET1.DIT -> det1__dit
        'name': name.replace(".", "__").lower(),
        # TODO: Reenable description
        # 'desc': v.get("label")[0],
        'desc': None,
        'unit': None,
        'type': python_from_type[v['type'][0]].__name__,
        'default': default_from_type[v['type'][0]],
        # TODO: Reenable defaults.
        # python_from_type[v['type'][0]](
        #     (v.get("value") if v.get("value")[0] else v.get("default"))[0]
        # )
    } for name, v in params.items()]

    list_attrs.insert(0, {
        'name': f"dummy_{name_template.lower()}",
        'desc': 'dummy',
        'unit': None,
        'type': int.__name__,
        'default': 42,
    })

    lines_attr = [
        f'    {a["name"]} = persistent("{a["desc"]} [{a["unit"]}]", {a["type"]}, ' +
        (f'"{a["default"]}"' if isinstance(a["default"], str) else f'{a["default"]}') + ')'
        for a in list_attrs
    ]
    s_attr = "\n\n".join(lines_attr)

    s_file = f'''# -*- coding: utf-8 -*-
"""
{doc_template}

This file is automatically generated. Do not modify!
"""

from micado.main.Template import Template, persistent


class {name_template}(Template):
    """
    {doc_template}
    """

{s_attr}'''

    print(s_file)
    return s_file


def main():
    fns_templates = sorted(glob.glob(f"{PATH_TEMPLATE_TSF}/*.tsf"))
    for fn_template in fns_templates:
        template_from_tsf(fn_template)


if __name__ == '__main__':
    main()

