# -*- coding: utf-8 -*-
"""
Terminology as used in the ESO archive.
"""

from enum import Flag, auto


class DprCategory(Flag):
    """
    Category of the observation. Multiple choices are allowed.

    Based
    - http://archive.eso.org/eso/eso_archive_help.html#DPR_category
    - Table 9 in http://archive.eso.org/cms/tools-documentation/dicb/ESO-044156_6DataInterfaceControlDocument.pdf
    - https://docs.google.com/spreadsheets/d/1BbQkf8l8fCPSYf7skE8y0GC2UMK8kPWBkjY0ojhZqVs/edit#gid=751586500
    """
    SCIENCE = auto()  # Any scientific object
    CALIB = auto()  # Any calibration source
    ACQUISITION = auto()  # Any scientific object
    TECHNICAL = auto()  # Any exposure taken to verify instrument performance/setup
    TEST = auto()  # Any exposure taken to test instrument performance/setup/software/conditions
    SIMULATION = auto()  # Any simulated exposure
    OTHER = auto()  # Any other exposure


class DprType(Flag):
    """
    Type of the observation. Multiple choices are allowed.

    Based on
    - http://archive.eso.org/eso/eso_archive_help.html#DPR_type
    - Table 10 in http://archive.eso.org/cms/tools-documentation/dicb/ESO-044156_6DataInterfaceControlDocument.pdf
    - https://docs.google.com/spreadsheets/d/1BbQkf8l8fCPSYf7skE8y0GC2UMK8kPWBkjY0ojhZqVs/edit#gid=751586500
    """

    # Principal Values:
    OBJECT = auto()  # Any observation of an unspecified object
    DARK = auto()  # Dark exposure (shutter closed)
    FLAT = auto()  # Any flat field exposure
    SLIT = auto()  #
    COLDMASK = auto()  #
    WARMMASK = auto()  #
    LAMPPUPIL = auto()  #
    WAFFLE = auto()  #

    # Qualifiers:
    SKY = auto()  # Any observation of an empty field on the sky
    LAMP = auto()  # Any lamp exposure
    DOME = auto()  # Any exposure using the dome
    SCREEN = auto()  # Any exposure using an illuminated screen
    FLUX = auto()  # Flux standard (spectroscopy and photometry)
